@@ -12,7 +12,7 @@ X:1
 T:Untitled Reel
 C:Trad.
 K:D
-eg|a2ab ageg|agbg agef|g2g2 fgag|f2d2 d2:|
+eg|a2-ab ageg|agbg agef|g2g2 fgag|f2d2 d2:|
 ed|cecA B2ed|cAcA E2ed|cecA B2ed|c2A2 A2:|
 AB|cdec BcdB|ABAF GFE2|cdec BcdB|c2A2 A2:|
 ";
